pub struct EdgeDefinition { /* private fields */ }Expand description
Directed connection from one output port to one input port.
Implementations
Sourceimpl EdgeDefinition
impl EdgeDefinition
Sourcepub const fn new(source: EdgeEndpoint, target: EdgeEndpoint) -> Self
pub const fn new(source: EdgeEndpoint, target: EdgeEndpoint) -> Self
Create an edge from an upstream endpoint to a downstream endpoint.
Sourcepub const fn with_capacity(
source: EdgeEndpoint,
target: EdgeEndpoint,
capacity: NonZeroUsize,
) -> Self
pub const fn with_capacity( source: EdgeEndpoint, target: EdgeEndpoint, capacity: NonZeroUsize, ) -> Self
Create an edge with an explicit bounded capacity.
Sourcepub const fn source(&self) -> &EdgeEndpoint
pub const fn source(&self) -> &EdgeEndpoint
Upstream output endpoint.
Sourcepub const fn target(&self) -> &EdgeEndpoint
pub const fn target(&self) -> &EdgeEndpoint
Downstream input endpoint.
Sourcepub const fn capacity(&self) -> EdgeCapacity
pub const fn capacity(&self) -> EdgeCapacity
Capacity policy for this edge.